package VMOMI::HostSpecification;
use parent 'VMOMI::DynamicData';

use strict;
use warnings;

our @class_ancestors = ( 
    'DynamicData',
);

our @class_members = ( 
    ['createdTime', undef, 0, ],
    ['lastModified', undef, 0, 1],
    ['host', 'ManagedObjectReference', 0, ],
    ['subSpecs', 'HostSubSpecification', 1, 1],
    ['changeID', undef, 0, 1],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
